==> nextcloud-19.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/tr.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "İşlemci bilgileri alınamadı",
    "Load average" : "Yük ortalaması",
    "Last minute" : "Son dakika",
    "Memory info not available" : "Bellek bilgilerine erişilemiyor",
    "Total" : "Toplam",
    "Current usage" : "Güncel kullanım",
    "Users" : "Kullanıcılar",
    "Groups" : "Gruplar",
    "Links" : "Bağlantılar",
    "Mails" : "E-postalar",
    "Federated sent" : "Birleşik gönderilen",
    "Federated received" : "Birleşik alınan",
    "Talk conversations" : "Sohbet görüşmeleri",
    "24 hours" : "24 saat",
    "1 hour" : "1 saat",
    "5 mins" : "5 dakika",
    "Copy" : "Kopyala",
    "Copied!" : "Kopyalandı!",
    "Not supported!" : "Desteklenmiyor!",
    "Press ⌘-C to copy." : "Kopyalamak için ⌘-C tuşlarına basın.",
    "Press Ctrl-C to copy." : "Kopyalamak için Ctrl-C tuşlarına basın.",
    "System" : "Sistem",
    "Monitoring" : "İzleniyor",
    "Monitoring app with useful server information" : "Yararlı sunucu bilgileri sunan izleme uygulaması",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "İşlemci yükü, bellek ve disk kullanımı, kullanıcı sayısı gibi sunucu hakkında çeşitli bilgiler sağlar. ",
    "Operating System" : "İşletim Sistemi",
    "CPU" : "İşlemci",
    "Memory" : "Bellek",
    "Server time" : "Sunucu Zamanı",
    "Uptime" : "Çalışma Süresi",
    "Time Servers" : "Saat Sunucuları",
    "Load" : "Yük",
    "Disk" : "Disk",
    "Mount" : "Bağlantı Noktası",
    "Filesystem" : "Dosya Sistemi",
    "Size" : "Boyut",
    "Available" : "Kullanılabilecek Alan",
    "Used" : "Kullanılan Alan",
    "You will get a notification once one of your disks is nearly full." : "Diskinizde boş alan azaldığında bir bildirim alacaksınız.",
    "Files:" : "Dosyalar:",
    "Storages:" : "Depolama Birimleri:",
    "Free Space:" : "Boş Alan:",
    "Network" : "Ağ",
    "Hostname" : "Sunucu Adı",
    "DNS" : "DNS",
    "Gateway" : "Ağ Geçidi",
    "Status" : "Durum",
    "Speed" : "Hız",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "Etkin kullanıcılar",
    "Total users:" : "Kullanıcı Sayısı:",
    "Shares" : "Paylaşımlar",
    "PHP" : "PHP",
    "Version:" : "Sürüm:",
    "Memory Limit:" : "Bellek Sınırı:",
    "Max Execution Time:" : "En Uzun Çalışma Süresi:",
    "Upload max size:" : "En büyük yükleme boyutu:",
    "Database" : "Veritabanı",
    "Type:" : "Tür:",
    "Size:" : "Boyut:",
    "External monitoring tool" : "Dış izleme aracı",
    "You can connect an external monitoring tool by using this end point:" : "Bu uç noktasını kullanarak bir dış izleme aracı bağlayabilirsiniz:",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Adresin sonuna \"?format=json\" eklendiğinde sonuçlar JSON biçiminde alınabilir.",
    "Last 24 hours" : "Son 24 saat",
    "Last 1 hour" : "Son 1 saat",
    "Last 5 mins" : "Son 5 dakika",
    "CPU load" : "İşlemci yükü",
    "Memory usage" : "Bellek kullanımı",
    "Storage" : "Depolama",
    "Users:" : "Kullanıcılar:",
    "Nextcloud" : "Nextcloud",
    "Apps installed:" : "Kurulu Uygulamalar:",
    "Apps updates available:" : "Güncellenebilecek Uygulamalar:",
    "Did you know?" : "Biliyor musunuz?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "Adresin sonuna \"?format=json\" eklendiğinde sonuçlar JSON biçiminde alınabilir!"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-20.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/tr.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "İşlemci bilgileri alınamadı",
    "Load average" : "Yük ortalaması",
    "Last minute" : "Son dakika",
    "Memory info not available" : "Bellek bilgilerine erişilemiyor",
    "Total" : "Toplam",
    "Current usage" : "Güncel kullanım",
    "Users" : "Kullanıcılar",
    "Groups" : "Gruplar",
    "Links" : "Bağlantılar",
    "Mails" : "E-postalar",
    "Federated sent" : "Birleşik gönderilen",
    "Federated received" : "Birleşik alınan",
    "Talk conversations" : "Talk görüşmeleri",
    "24 hours" : "24 saat",
    "1 hour" : "1 saat",
    "5 mins" : "5 dakika",
    "Copy" : "Kopyala",
    "Copied!" : "Kopyalandı!",
    "Not supported!" : "Desteklenmiyor!",
    "Press ⌘-C to copy." : "Kopyalamak için ⌘-C tuşlarına basın.",
    "Press Ctrl-C to copy." : "Kopyalamak için Ctrl-C tuşlarına basın.",
    "System" : "Sistem",
    "Monitoring" : "İzleniyor",
    "Monitoring app with useful server information" : "Yararlı sunucu bilgileri sunan izleme uygulaması",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "İşlemci yükü, bellek ve disk kullanımı, kullanıcı sayısı gibi sunucu hakkında çeşitli bilgiler sağlar. ",
    "Operating System" : "İşletim Sistemi",
    "CPU" : "İşlemci",
    "Memory" : "Bellek",
    "Server time" : "Sunucu Zamanı",
    "Uptime" : "Çalışma Süresi",
    "Load" : "Yük",
    "Disk" : "Disk",
    "Mount" : "Bağlantı Noktası",
    "Filesystem" : "Dosya Sistemi",
    "Size" : "Boyut",
    "Available" : "Kullanılabilecek Alan",
    "Used" : "Kullanılan Alan",
    "You will get a notification once one of your disks is nearly full." : "Diskinizde boş alan azaldığında bir bildirim alacaksınız.",
    "Files:" : "Dosyalar:",
    "Storages:" : "Depolama Birimleri:",
    "Free Space:" : "Boş Alan:",
    "Network" : "Ağ",
    "Hostname" : "Sunucu Adı",
    "DNS" : "DNS",
    "Gateway" : "Ağ Geçidi",
    "Status" : "Durum",
    "Speed" : "Hız",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "Etkin kullanıcılar",
    "Total users:" : "Kullanıcı Sayısı:",
    "Shares" : "Paylaşımlar",
    "PHP" : "PHP",
    "Version:" : "Sürüm:",
    "Memory Limit:" : "Bellek Sınırı:",
    "Max Execution Time:" : "En Uzun Çalışma Süresi:",
    "Upload max size:" : "En büyük yükleme boyutu:",
    "Database" : "Veritabanı",
    "Type:" : "Tür:",
    "Size:" : "Boyut:",
    "External monitoring tool" : "Dış izleme aracı",
    "You can connect an external monitoring tool by using this end point:" : "Bu uç noktasını kullanarak bir dış izleme aracı bağlayabilirsiniz:",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Adresin sonuna \"?format=json\" eklendiğinde sonuçlar JSON biçiminde alınabilir.",
    "Time Servers" : "Saat Sunucuları",
    "Did you know?" : "Biliyor musunuz?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "Adresin sonuna \"?format=json\" eklendiğinde sonuçlar JSON biçiminde alınabilir!"
},
"nplurals=2; plural=(n > 1);");
